@@ -42,7 +42,7 @@ crsivderiv <- function(y,
                          "EPSILON"=.Machine$double.eps,
                          "INITIAL_MESH_SIZE"="r1.0e-01",
                          "MIN_MESH_SIZE"=paste("r",sqrt(.Machine$double.eps),sep=""),
-                         "MIN_POLL_SIZE"=paste("r",sqrt(.Machine$double.eps),sep=""),
+                         "MIN_POLL_SIZE"=paste("r",1,sep=""),
                          "DISPLAY_DEGREE"=0),
                        ...) {
   
