@@ -1,44 +1,46 @@
-/*-------------------------------------------------------------------------------------*/
-/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search - version 3.8.0      */
-/*                                                                                     */
-/*                                                                                     */
-/*  NOMAD - version 3.8.0 has been created by                                          */
-/*                 Charles Audet        - Ecole Polytechnique de Montreal              */
-/*                 Sebastien Le Digabel - Ecole Polytechnique de Montreal              */
-/*                 Christophe Tribes    - Ecole Polytechnique de Montreal              */
-/*                                                                                     */
-/*  The copyright of NOMAD - version 3.8.0 is owned by                                 */
-/*                 Sebastien Le Digabel - Ecole Polytechnique de Montreal              */
-/*                 Christophe Tribes    - Ecole Polytechnique de Montreal              */
-/*                                                                                     */
-/*  NOMAD v3 has been funded by AFOSR and Exxon Mobil.                                 */
-/*                                                                                     */
-/*  NOMAD v3 is a new version of NOMAD v1 and v2. NOMAD v1 and v2 were created and     */
-/*  developed by Mark Abramson, Charles Audet, Gilles Couture and John E. Dennis Jr.,  */
-/*  and were funded by AFOSR and Exxon Mobil.                                          */
-/*                                                                                     */
-/*                                                                                     */
-/*  Contact information:                                                               */
-/*    Ecole Polytechnique de Montreal - GERAD                                          */
-/*    C.P. 6079, Succ. Centre-ville, Montreal (Quebec) H3C 3A7 Canada                  */
-/*    e-mail: nomad@gerad.ca                                                           */
-/*    phone : 1-514-340-6053 #6928                                                     */
-/*    fax   : 1-514-340-5665                                                           */
-/*                                                                                     */
-/*  This program is free software: you can redistribute it and/or modify it under the  */
-/*  terms of the GNU Lesser General Public License as published by the Free Software   */
-/*  Foundation, either version 3 of the License, or (at your option) any later         */
-/*  version.                                                                           */
-/*                                                                                     */
-/*  This program is distributed in the hope that it will be useful, but WITHOUT ANY    */
-/*  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A    */
-/*  PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.   */
-/*                                                                                     */
-/*  You should have received a copy of the GNU Lesser General Public License along     */
-/*  with this program. If not, see <http://www.gnu.org/licenses/>.                     */
-/*                                                                                     */
-/*  You can find information on the NOMAD software at www.gerad.ca/nomad               */
-/*-------------------------------------------------------------------------------------*/
+/*---------------------------------------------------------------------------------*/
+/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search -                */
+/*                                                                                 */
+/*  NOMAD - version 3.9.1 has been created by                                      */
+/*                 Charles Audet               - Ecole Polytechnique de Montreal   */
+/*                 Sebastien Le Digabel        - Ecole Polytechnique de Montreal   */
+/*                 Viviane Rochon Montplaisir - Ecole Polytechnique de Montreal   */
+/*                 Christophe Tribes           - Ecole Polytechnique de Montreal   */
+/*                                                                                 */
+/*  The copyright of NOMAD - version 3.9.1 is owned by                             */
+/*                 Sebastien Le Digabel        - Ecole Polytechnique de Montreal   */
+/*                 Viviane Rochon Montplaisir - Ecole Polytechnique de Montreal   */
+/*                 Christophe Tribes           - Ecole Polytechnique de Montreal   */
+/*                                                                                 */
+/*  NOMAD v3 has been funded by AFOSR and Exxon Mobil.                             */
+/*                                                                                 */
+/*  NOMAD v3 is a new version of NOMAD v1 and v2. NOMAD v1 and v2 were created     */
+/*  and developed by Mark Abramson, Charles Audet, Gilles Couture, and John E.     */
+/*  Dennis Jr., and were funded by AFOSR and Exxon Mobil.                          */
+/*                                                                                 */
+/*  Contact information:                                                           */
+/*    Ecole Polytechnique de Montreal - GERAD                                      */
+/*    C.P. 6079, Succ. Centre-ville, Montreal (Quebec) H3C 3A7 Canada              */
+/*    e-mail: nomad@gerad.ca                                                       */
+/*    phone : 1-514-340-6053 #6928                                                 */
+/*    fax   : 1-514-340-5665                                                       */
+/*                                                                                 */
+/*  This program is free software: you can redistribute it and/or modify it        */
+/*  under the terms of the GNU Lesser General Public License as published by       */
+/*  the Free Software Foundation, either version 3 of the License, or (at your     */
+/*  option) any later version.                                                     */
+/*                                                                                 */
+/*  This program is distributed in the hope that it will be useful, but WITHOUT    */
+/*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or          */
+/*  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License    */
+/*  for more details.                                                              */
+/*                                                                                 */
+/*  You should have received a copy of the GNU Lesser General Public License       */
+/*  along with this program. If not, see <http://www.gnu.org/licenses/>.           */
+/*                                                                                 */
+/*  You can find information on the NOMAD software at www.gerad.ca/nomad           */
+/*---------------------------------------------------------------------------------*/
+
 /**
  \file   OrthogonalMesh.hpp
  \brief  implementation
@@ -51,19 +53,21 @@
 
 /// Constructor (called only by derived objects).
 NOMAD::OrthogonalMesh::OrthogonalMesh (bool                   anisotropic_mesh ,
+                                       NOMAD::Double           anisotropy_factor,
                                        const NOMAD::Point    & Delta_0   ,
                                        const NOMAD::Point    & Delta_min ,
                                        const NOMAD::Point    & delta_min ,
-                                       const NOMAD::Point   & fixed_variables ,
-                                       const NOMAD::Point   & granularity ,
-                                       NOMAD::Double            update_basis,
+                                       const NOMAD::Point    & fixed_variables ,
+                                       const NOMAD::Point    & granularity ,
+                                       NOMAD::Double           update_basis,
                                        int                     coarsening_step,
                                        int                     refining_step,
-                                       int                   limit_mesh_index ) :
+                                       int                     limit_mesh_index) :
 _anisotropic_mesh   ( anisotropic_mesh ),
+_anisotropy_factor  ( anisotropy_factor ),
 _delta_0            ( Delta_0 ),
-Delta_Delta_0            ( Delta_0 ),
-Delta_Delta_min          ( Delta_min ),
+D_Delta_0            ( Delta_0 ),
+D_Delta_min          ( Delta_min ),
 _delta_min          ( delta_min ),
 _fixed_variables    ( fixed_variables ),
 _granularity        ( granularity ),
@@ -73,9 +77,9 @@ _refining_step      ( refining_step ),
 _limit_mesh_index   ( limit_mesh_index )
 {
     
-    
-    Delta_Delta_min_is_defined = Delta_Delta_min.is_defined();
-    Delta_Delta_min_is_complete = Delta_Delta_min.is_complete();
+
+    D_Delta_min_is_defined = D_Delta_min.is_defined();
+    D_Delta_min_is_complete = D_Delta_min.is_complete();
     
     _delta_min_is_defined = _delta_min.is_defined();
     _delta_min_is_complete = _delta_min.is_complete();
@@ -88,7 +92,7 @@ _limit_mesh_index   ( limit_mesh_index )
         throw NOMAD::Exception ( "OrthogonalMesh.hpp" , __LINE__ ,
                                 "NOMAD::OrthogonalMesh::OrthogonalMesh(): granularity has undefined values" );
     
-    if ( !Delta_Delta_0.is_complete() )
+    if ( !D_Delta_0.is_complete() )
         throw NOMAD::Exception (  "OrthogonalMesh.hpp" , __LINE__ ,
                                 "NOMAD::OrthogonalMesh::OrthogonalMesh(): delta_0 has undefined values" );
     
@@ -96,13 +100,15 @@ _limit_mesh_index   ( limit_mesh_index )
         throw NOMAD::Exception ( "OrthogonalMesh.hpp" , __LINE__ ,
                                 "NOMAD::OrthogonalMesh::OrthogonalMesh(): delta_0 and delta_min have different sizes" );
     
-    if ( Delta_Delta_min_is_defined && Delta_min.size() != _n )
+    if ( D_Delta_min_is_defined && Delta_min.size() != _n )
         throw NOMAD::Exception ( "OrthogonalMesh.hpp" , __LINE__ ,
                                 "NOMAD::OrthogonalMesh::OrthogonalMesh(): Delta_0 and Delta_min have different sizes" );
     
     
     std::string error;
-    _all_granular = ( _granularity.is_defined() && _granularity.is_complete() ) ? true:false ;
+    // _all_granular is true if all variables are granular; fixed variables are ignored.
+    _all_granular = (_granularity.is_defined()) ? true : false;
+
     for ( int k = 0 ; k < _n ; ++k )
     {
         // we check that Delta_min <= Delta_0 and that delta_min <= delta_0:
@@ -113,16 +119,18 @@ _limit_mesh_index   ( limit_mesh_index )
             error = "NOMAD::OrthogonalMesh::OrthogonalMesh(): delta_0 < delta_min";
             break;
         }
-        if ( Delta_Delta_min_is_defined &&
-            Delta_Delta_min[k].is_defined()                        &&
-            Delta_Delta_0[k] < Delta_Delta_min[k]     )
+        if ( D_Delta_min_is_defined &&
+            D_Delta_min[k].is_defined()                        &&
+            D_Delta_0[k] < D_Delta_min[k]     )
         {
             error = "NOMAD::OrthogonalMesh::OrthogonalMesh(): Delta_0 < Delta_min";
             break;
         }
         
-        if ( _all_granular && _granularity[k] == 0 )
+        if ( _all_granular && !_fixed_variables[k].is_defined() && _granularity[k] == 0 )
+        {
             _all_granular = false;
+        }
         
     }
     
@@ -178,11 +186,17 @@ void NOMAD::OrthogonalMesh::set_min_mesh_sizes ( const NOMAD::Point & delta_min
     {
         
         // we check that Delta_min <= Delta_0 and that delta_min <= delta_0:
-        if ( delta_min[k].is_defined() && _delta_0[k] < delta_min[k] )
+        if ( delta_min[k].is_defined()    &&
+            _delta_0[k] < delta_min[k]        )
+        {
             _delta_min[k]=_delta_0[k];
+        }
+        if ( delta_min[k].is_defined()    &&
+            D_Delta_0[k] < delta_min[k]     )
+        {
+            _delta_min[k]=D_Delta_0[k];
+        }
         
-        if ( delta_min[k].is_defined() && Delta_Delta_0[k] < delta_min[k] )
-            _delta_min[k]=Delta_Delta_0[k];
     }
     
     if ( !error.empty() )
@@ -196,12 +210,12 @@ void NOMAD::OrthogonalMesh::set_min_mesh_sizes ( const NOMAD::Point & delta_min
 void NOMAD::OrthogonalMesh::set_min_poll_sizes ( const NOMAD::Point & Delta_min )
 {
     
-    // If Delta_min undefined than Delta_Delta_min->undefined
+    // If Delta_min undefined than _Delta_min->undefined
     if ( ! Delta_min.is_defined() )
     {
-        Delta_Delta_min.clear();
-        Delta_Delta_min_is_defined = false;
-        Delta_Delta_min_is_complete = false;
+        D_Delta_min.clear();
+        D_Delta_min_is_defined = false;
+        D_Delta_min_is_complete = false;
         return;
     }
     
@@ -215,17 +229,17 @@ void NOMAD::OrthogonalMesh::set_min_poll_sizes ( const NOMAD::Point & Delta_min
         throw NOMAD::Exception (  "OrthogonalMesh.hpp" , __LINE__ ,
                                 "set_min_poll_sizes(): Delta_min has some defined and undefined values" );
     
-    Delta_Delta_min.reset( _n );
-    Delta_Delta_min = Delta_min;
-    Delta_Delta_min_is_defined = true;
-    Delta_Delta_min_is_complete = true;
+    D_Delta_min.reset( _n );
+    D_Delta_min = Delta_min;
+    D_Delta_min_is_defined = true;
+    D_Delta_min_is_complete = true;
     
     std::string error;
     for ( int k = 0 ; k < _n ; ++k )
     {
         // we check that Delta_min <= Delta_0 :
-        if ( Delta_min[k].is_defined() && Delta_Delta_0[k] < Delta_min[k] )
-            Delta_Delta_min[k]=Delta_Delta_0[k];
+        if ( Delta_min[k].is_defined() && D_Delta_0[k] < Delta_min[k] )
+            D_Delta_min[k]=D_Delta_0[k];
     }
     
     if ( !error.empty() )
@@ -254,9 +268,9 @@ void NOMAD::OrthogonalMesh::set_delta_0 ( const NOMAD::Point & d )
 void NOMAD::OrthogonalMesh::set_Delta_0 ( const NOMAD::Point & d )
 {
     
-    if ( d.size() != Delta_Delta_0.size() )
+    if ( d.size() != D_Delta_0.size() )
         throw NOMAD::Exception ( "XMesh.cpp" , __LINE__ ,
                                 "NOMAD::XMesh::set_Delta_0(): dimension of provided Delta_0 must be consistent with their previous dimension" );
     
-    Delta_Delta_0=d;
+    D_Delta_0=d;
 }
